#!/bin/sh
# UnlimitedDataBackup.com 5.5.7.0

######################### START: User Defined Section ##########################

# ------------------------------- BACKUP_SET --------------------------------- #
# The name of the backup set that you want to run                              #
# If backup set name is not in English, please use BackupSetID                 #
# e.g. SET BACKUP_SET="1119083740107"                                          #
#  or  SET BACKUP_SET="FileBackupSet-1"                                        #
# ---------------------------------------------------------------------------- #
BACKUP_SET=$1

# ------------------------------- BACKUP_TYPE -------------------------------- #
# Set backup type. You don't need to change this if you are backing up a       #
# file backup set.                                                             #
# Options available: FILE/DATABASE/DIFFERENTIAL/LOG                            #
# e.g. SET BACKUP_TYPE=FILE          for file backup                           #
#  or  SET BACKUP_TYPE=DATABASE      for Full database backup                  #
#  or  SET BACKUP_TYPE=DIFFERENTIAL  for Differential database backup          #
#  or  SET BACKUP_TYPE=LOG           for Log database backup                   #
# ---------------------------------------------------------------------------- #
BACKUP_TYPE=FILE

# ------------------------------- CONFIG_HOME ------------------------------- #
# Directory to your setting home. Default to ~/.acb when not set.      #
# e.g. CONFIG_HOME=~/.acb                                                     #
# ---------------------------------------------------------------------------- #
CONFIG_HOME=${HOME}/.acb

# -------------------------------- DELTA_HOME -------------------------------- #
# Set In-File Delta mode.                                                      #
# Options available: Incremental/Differential/Full (I/D/F)                     #
# e.g. SET DELTA_MODE="I"   for Incremental In-file delta backup               #
#  or  SET DELTA_MODE="D"   for Differential In-file delta backup              #
#  or  SET DELTA_MODE="F"   for Full File backup                               #
#  or  SET DELTA_MODE=""    for using backup set in-file delta setting         #
# ---------------------------------------------------------------------------- #
DELTA_MODE=""

# -------------------------------- DEBUG_MODE -------------------------------- #
# Set Debug mode.                                                              #
# Options available: DEBUG/NO-DEBUG                                            #
# e.g. SET DEBUG_MODE=DEBUG                                                    #
#  or  SET DEBUG_MODE=NO-DEBUG                                                 #
# ---------------------------------------------------------------------------- #
DEBUG_MODE=NO-DEBUG

########################## END: User Defined Section ###########################


################################################################################
#          S C R I P T     U S A G E                                           #
################################################################################
if [ -z "$BACKUP_SET" ]; then
    echo "Usage: RunBackupSet.sh [BackupSetName | BackupSetID]"
    echo "or, set BACKUP_SET in RunBackupSet.sh"
    exit 0;
fi

################################################################################
#          R E T R I E V E     A P P _ H O M E     P A T H                     #
################################################################################

EXE_DIR=`pwd`
SCRIPT_HOME=`dirname "$0"`
cd "$SCRIPT_HOME"
APP_BIN=`pwd`
APP_HOME=`dirname "$APP_BIN"`

################################################################################
#          R E T R I E V E     J A V A _ H O M E     P A T H                   #
################################################################################

if [ Darwin = `uname` ]; then
    JAVA_HOME=/System/Library/Frameworks/JavaVM.framework/Home
fi

if [ ! -x "$APP_HOME/jvm" ];
then
    echo "$APP_HOME/jvm does not exist!"
    if [ ! -n "$JAVA_HOME" ]; then
        echo "Please set JAVA_HOME!"
        exit 0
    else
        ln -sf "$JAVA_HOME" "$APP_HOME/jvm"
        echo "Created JAVA_HOME symbolic link at $APP_HOME/jvm"
    fi
fi

if [ ! -x "$APP_HOME/jvm" ];
then
    echo "Please create symbolic link for '$JAVA_HOME' to '$APP_HOME/jvm'"
    exit 0
fi

JAVA_HOME="$APP_HOME/jvm"
JAVA_EXE="$JAVA_HOME/bin/java"

################################################################################
#          E X E C U T I O N     J A V A     P R O P E R T I E S               #
################################################################################

# Set LD_LIBRARY_PATH for Lotus Notes on Linux
if [ Linux = `uname` ];
then
    NOTES_PROGRAM=`cat "$APP_HOME/bin/notesenv"`
    LD_LIBRARY_PATH=$APP_HOME/bin:$NOTES_PROGRAM:$LD_LIBRARY_PATH
    export NOTES_PROGRAM
else
    LD_LIBRARY_PATH=$APP_HOME/bin:$LD_LIBRARY_PATH
fi

SHLIB_PATH=LD_LIBRARY_PATH
export LD_LIBRARY_PATH SHLIB_PATH

################################################################################
#          J A V A     E X E C U T I O N                                       #
################################################################################

# Change to APP_HOME for JAVA execution
cd "${APP_HOME}"

# Reference path will be used to avoid empty space in the parent directory
LIB_HOME=./bin
JAVA_OPTS="-Xrs -Xmx256m -client"
JNI_PATH="-Djava.library.path=$LIB_HOME"
CLASSPATH="$LIB_HOME:$LIB_HOME/obc.jar:$LIB_HOME/obc-lib.jar"
MAIN_CLASS=RunBackupSet

echo "Using APP_HOME:    : $APP_HOME"
echo "Using BACKUP_SET   : $BACKUP_SET"
echo "Using BACKUP_TYPE  : $BACKUP_TYPE"
echo "Using CONFIG_HOME : $CONFIG_HOME"
echo "Using DELTA_MODE   : $DELTA_MODE"
echo "Using DEBUG_MODE   : $DEBUG_MODE"

# API Arguments: RunBackupSet [APP_HOME] [BACKUP-SET] [BACKUP-TYPE] [CONFIG_HOME] option: [DELTA-TYPE] [MODE:DEBUG]

# Do not include double-quote for java options, jni path, classpath and main class
# Only apply double-quote for path to java executable and execution arguments
"${JAVA_EXE}" $JAVA_OPTS $JNI_PATH -cp $CLASSPATH $MAIN_CLASS . "${BACKUP_SET}" "${BACKUP_TYPE}" "${CONFIG_HOME}" "${DELTA_MODE}" "${DEBUG_MODE}"

###############################################################################
#                   R E S E T          A N D          E X I T                 #
###############################################################################

cd "${EXE_DIR}"
exit 0
